# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def BinaryBackoff(self):
		"""The percentage to be applied to the search interval through which the next iterations rate is obtained.

		Returns:
			number
		"""
		return self._get_attribute('binaryBackoff')
	@BinaryBackoff.setter
	def BinaryBackoff(self, value):
		self._set_attribute('binaryBackoff', value)

	@property
	def BinaryFrameLossUnit(self):
		"""The binary frame loss unit.

		Returns:
			str(%|frames)
		"""
		return self._get_attribute('binaryFrameLossUnit')
	@BinaryFrameLossUnit.setter
	def BinaryFrameLossUnit(self, value):
		self._set_attribute('binaryFrameLossUnit', value)

	@property
	def BinaryLoadUnit(self):
		"""The binary load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('binaryLoadUnit')
	@BinaryLoadUnit.setter
	def BinaryLoadUnit(self, value):
		self._set_attribute('binaryLoadUnit', value)

	@property
	def BinaryResolution(self):
		"""The resolution of the iteration during a binary search.

		Returns:
			number
		"""
		return self._get_attribute('binaryResolution')
	@BinaryResolution.setter
	def BinaryResolution(self, value):
		self._set_attribute('binaryResolution', value)

	@property
	def BinarySearchType(self):
		"""The binary search type.

		Returns:
			str(linear|perFlow|perPort)
		"""
		return self._get_attribute('binarySearchType')
	@BinarySearchType.setter
	def BinarySearchType(self, value):
		self._set_attribute('binarySearchType', value)

	@property
	def BinaryTolerance(self):
		"""The percentage of frame loss that is acceptable in order for an iteration to be considered successful during a binary search.

		Returns:
			number
		"""
		return self._get_attribute('binaryTolerance')
	@BinaryTolerance.setter
	def BinaryTolerance(self, value):
		self._set_attribute('binaryTolerance', value)

	@property
	def BurstSize(self):
		"""It signifies the burst size of the protocol.

		Returns:
			number
		"""
		return self._get_attribute('burstSize')
	@BurstSize.setter
	def BurstSize(self, value):
		self._set_attribute('burstSize', value)

	@property
	def CalculateJitter(self):
		"""If true, enables jitter calculation.

		Returns:
			bool
		"""
		return self._get_attribute('calculateJitter')
	@CalculateJitter.setter
	def CalculateJitter(self, value):
		self._set_attribute('calculateJitter', value)

	@property
	def CalculateLatency(self):
		"""If true, enables latency calculation.

		Returns:
			bool
		"""
		return self._get_attribute('calculateLatency')
	@CalculateLatency.setter
	def CalculateLatency(self, value):
		self._set_attribute('calculateLatency', value)

	@property
	def ComboBackoff(self):
		"""The percentage to be applied to the search interval through which the next iterations rate is obtained, for Combo Load Type.

		Returns:
			number
		"""
		return self._get_attribute('comboBackoff')
	@ComboBackoff.setter
	def ComboBackoff(self, value):
		self._set_attribute('comboBackoff', value)

	@property
	def ComboFrameLossUnit(self):
		"""The combo frame loss unit.

		Returns:
			str(%|frames)
		"""
		return self._get_attribute('comboFrameLossUnit')
	@ComboFrameLossUnit.setter
	def ComboFrameLossUnit(self, value):
		self._set_attribute('comboFrameLossUnit', value)

	@property
	def ComboLoadUnit(self):
		"""The combo Load Unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('comboLoadUnit')
	@ComboLoadUnit.setter
	def ComboLoadUnit(self, value):
		self._set_attribute('comboLoadUnit', value)

	@property
	def ComboResolution(self):
		"""The resolution of the iteration for Combo Load Type.

		Returns:
			number
		"""
		return self._get_attribute('comboResolution')
	@ComboResolution.setter
	def ComboResolution(self, value):
		self._set_attribute('comboResolution', value)

	@property
	def ComboTolerance(self):
		"""The value of the tolerance level for Combo Load Type.

		Returns:
			number
		"""
		return self._get_attribute('comboTolerance')
	@ComboTolerance.setter
	def ComboTolerance(self, value):
		self._set_attribute('comboTolerance', value)

	@property
	def CountRandomFrameSize(self):
		"""If true, randomly counts the frame size.

		Returns:
			number
		"""
		return self._get_attribute('countRandomFrameSize')
	@CountRandomFrameSize.setter
	def CountRandomFrameSize(self, value):
		self._set_attribute('countRandomFrameSize', value)

	@property
	def CustomLoadUnit(self):
		"""The custom load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('customLoadUnit')
	@CustomLoadUnit.setter
	def CustomLoadUnit(self, value):
		self._set_attribute('customLoadUnit', value)

	@property
	def DelayAfterTransmit(self):
		"""Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def DetailedResultsEnabled(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('detailedResultsEnabled')
	@DetailedResultsEnabled.setter
	def DetailedResultsEnabled(self, value):
		self._set_attribute('detailedResultsEnabled', value)

	@property
	def Duration(self):
		"""The duration of the test in hours, which is used to calculate the number of framesto transmit.

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableDataIntegrity(self):
		"""If true, enables data integrity test.

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrity')
	@EnableDataIntegrity.setter
	def EnableDataIntegrity(self, value):
		self._set_attribute('enableDataIntegrity', value)

	@property
	def EnableExtraIterations(self):
		"""If true, enables the tracking option in aggregation files.

		Returns:
			bool
		"""
		return self._get_attribute('enableExtraIterations')
	@EnableExtraIterations.setter
	def EnableExtraIterations(self, value):
		self._set_attribute('enableExtraIterations', value)

	@property
	def EnableFastConvergence(self):
		"""If true, enables fast convergence.

		Returns:
			bool
		"""
		return self._get_attribute('enableFastConvergence')
	@EnableFastConvergence.setter
	def EnableFastConvergence(self, value):
		self._set_attribute('enableFastConvergence', value)

	@property
	def EnableLayer1Rate(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer1Rate')
	@EnableLayer1Rate.setter
	def EnableLayer1Rate(self, value):
		self._set_attribute('enableLayer1Rate', value)

	@property
	def EnableMinFrameSize(self):
		"""If true, enables minimum frame size.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def EnableOldStatsForReef(self):
		"""Enables old statistics for reef.

		Returns:
			bool
		"""
		return self._get_attribute('enableOldStatsForReef')
	@EnableOldStatsForReef.setter
	def EnableOldStatsForReef(self, value):
		self._set_attribute('enableOldStatsForReef', value)

	@property
	def ExtraIterationOffsets(self):
		"""Sets extra iteration offset values.

		Returns:
			str
		"""
		return self._get_attribute('extraIterationOffsets')
	@ExtraIterationOffsets.setter
	def ExtraIterationOffsets(self, value):
		self._set_attribute('extraIterationOffsets', value)

	@property
	def FastConvergenceDuration(self):
		"""sec

		Returns:
			number
		"""
		return self._get_attribute('fastConvergenceDuration')
	@FastConvergenceDuration.setter
	def FastConvergenceDuration(self, value):
		self._set_attribute('fastConvergenceDuration', value)

	@property
	def FastConvergenceThreshold(self):
		"""If true, enables fast convergence threshold value.

		Returns:
			number
		"""
		return self._get_attribute('fastConvergenceThreshold')
	@FastConvergenceThreshold.setter
	def FastConvergenceThreshold(self, value):
		self._set_attribute('fastConvergenceThreshold', value)

	@property
	def ForceRegenerate(self):
		"""Initiates a forced regeneration.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FrameLossUnit(self):
		"""The frame loss unit.

		Returns:
			str
		"""
		return self._get_attribute('frameLossUnit')
	@FrameLossUnit.setter
	def FrameLossUnit(self, value):
		self._set_attribute('frameLossUnit', value)

	@property
	def FrameOrderingByRfc2889(self):
		"""If true, indicates frame ordering by Rfc2889.

		Returns:
			bool
		"""
		return self._get_attribute('frameOrderingByRfc2889')
	@FrameOrderingByRfc2889.setter
	def FrameOrderingByRfc2889(self, value):
		self._set_attribute('frameOrderingByRfc2889', value)

	@property
	def FrameSizeMode(self):
		"""This attribute is the frame size mode for the Quad Gaussian.

		Returns:
			str(custom|customlist|increment|random)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def FramesPerBurstGap(self):
		"""It signifies the frames per burst gap.

		Returns:
			number
		"""
		return self._get_attribute('framesPerBurstGap')
	@FramesPerBurstGap.setter
	def FramesPerBurstGap(self, value):
		self._set_attribute('framesPerBurstGap', value)

	@property
	def Framesize(self):
		"""Bytes

		Returns:
			number
		"""
		return self._get_attribute('framesize')
	@Framesize.setter
	def Framesize(self, value):
		self._set_attribute('framesize', value)

	@property
	def FramesizeList(self):
		"""List containing the frame sizes used in the test.

		Returns:
			list(str)
		"""
		return self._get_attribute('framesizeList')
	@FramesizeList.setter
	def FramesizeList(self, value):
		self._set_attribute('framesizeList', value)

	@property
	def Gap(self):
		"""Inter-frame gap.

		Returns:
			number
		"""
		return self._get_attribute('gap')
	@Gap.setter
	def Gap(self, value):
		self._set_attribute('gap', value)

	@property
	def GenerateTrackingOptionAggregationFiles(self):
		"""If true, enables the tracking option in aggregation files.

		Returns:
			bool
		"""
		return self._get_attribute('generateTrackingOptionAggregationFiles')
	@GenerateTrackingOptionAggregationFiles.setter
	def GenerateTrackingOptionAggregationFiles(self, value):
		self._set_attribute('generateTrackingOptionAggregationFiles', value)

	@property
	def InitialBinaryLoadRate(self):
		"""The load rate used in the first iteration for each frame size during a binary search.

		Returns:
			number
		"""
		return self._get_attribute('initialBinaryLoadRate')
	@InitialBinaryLoadRate.setter
	def InitialBinaryLoadRate(self, value):
		self._set_attribute('initialBinaryLoadRate', value)

	@property
	def InitialComboLoadRate(self):
		"""The initial value of the load rate for Combo Load Type.

		Returns:
			number
		"""
		return self._get_attribute('initialComboLoadRate')
	@InitialComboLoadRate.setter
	def InitialComboLoadRate(self, value):
		self._set_attribute('initialComboLoadRate', value)

	@property
	def InitialStepLoadRate(self):
		"""The initial value of the load rate for Step Load Type.

		Returns:
			number
		"""
		return self._get_attribute('initialStepLoadRate')
	@InitialStepLoadRate.setter
	def InitialStepLoadRate(self, value):
		self._set_attribute('initialStepLoadRate', value)

	@property
	def LatencyBins(self):
		"""DEPRECATED Sets the latency bins statistics

		Returns:
			str
		"""
		return self._get_attribute('latencyBins')
	@LatencyBins.setter
	def LatencyBins(self, value):
		self._set_attribute('latencyBins', value)

	@property
	def LatencyBinsEnabled(self):
		"""DEPRECATED Enables the latency bins statistics

		Returns:
			bool
		"""
		return self._get_attribute('latencyBinsEnabled')
	@LatencyBinsEnabled.setter
	def LatencyBinsEnabled(self, value):
		self._set_attribute('latencyBinsEnabled', value)

	@property
	def LatencyType(self):
		"""DEPRECATED The type of latency.

		Returns:
			str(cutThrough|storeForward)
		"""
		return self._get_attribute('latencyType')
	@LatencyType.setter
	def LatencyType(self, value):
		self._set_attribute('latencyType', value)

	@property
	def LoadRateList(self):
		"""DEPRECATED The list of Load Rate.

		Returns:
			str
		"""
		return self._get_attribute('loadRateList')
	@LoadRateList.setter
	def LoadRateList(self, value):
		self._set_attribute('loadRateList', value)

	@property
	def LoadType(self):
		"""DEPRECATED The type of load.

		Returns:
			str(binary|combo|custom|quickSearch|step|unchanged)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def MapType(self):
		"""DEPRECATED The POS traffic map type.

		Returns:
			str
		"""
		return self._get_attribute('mapType')
	@MapType.setter
	def MapType(self, value):
		self._set_attribute('mapType', value)

	@property
	def MaxBinaryLoadRate(self):
		"""DEPRECATED The lower bound of the iteration rates for each frame size during a binary search.

		Returns:
			number
		"""
		return self._get_attribute('maxBinaryLoadRate')
	@MaxBinaryLoadRate.setter
	def MaxBinaryLoadRate(self, value):
		self._set_attribute('maxBinaryLoadRate', value)

	@property
	def MaxComboLoadRate(self):
		"""DEPRECATED The maximum value of the load rate Combo Load Type.

		Returns:
			number
		"""
		return self._get_attribute('maxComboLoadRate')
	@MaxComboLoadRate.setter
	def MaxComboLoadRate(self, value):
		self._set_attribute('maxComboLoadRate', value)

	@property
	def MaxIncrementFrameSize(self):
		"""DEPRECATED The maximum incremental value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('maxIncrementFrameSize')
	@MaxIncrementFrameSize.setter
	def MaxIncrementFrameSize(self, value):
		self._set_attribute('maxIncrementFrameSize', value)

	@property
	def MaxQuickSearchLoadRate(self):
		"""DEPRECATED Sets the maximum QuickSearch load rate

		Returns:
			number
		"""
		return self._get_attribute('maxQuickSearchLoadRate')
	@MaxQuickSearchLoadRate.setter
	def MaxQuickSearchLoadRate(self, value):
		self._set_attribute('maxQuickSearchLoadRate', value)

	@property
	def MaxRandomFrameSize(self):
		"""DEPRECATED The maximum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('maxRandomFrameSize')
	@MaxRandomFrameSize.setter
	def MaxRandomFrameSize(self, value):
		self._set_attribute('maxRandomFrameSize', value)

	@property
	def MaxStepLoadRate(self):
		"""DEPRECATED The maximum value of the load rate Step Load Type.

		Returns:
			number
		"""
		return self._get_attribute('maxStepLoadRate')
	@MaxStepLoadRate.setter
	def MaxStepLoadRate(self, value):
		self._set_attribute('maxStepLoadRate', value)

	@property
	def MinBinaryLoadRate(self):
		"""DEPRECATED The lower bound of the iteration rates for each frame size during a binary search.

		Returns:
			number
		"""
		return self._get_attribute('minBinaryLoadRate')
	@MinBinaryLoadRate.setter
	def MinBinaryLoadRate(self, value):
		self._set_attribute('minBinaryLoadRate', value)

	@property
	def MinComboLoadRate(self):
		"""DEPRECATED The minimum value of the load rate Combo Load Type.

		Returns:
			number
		"""
		return self._get_attribute('minComboLoadRate')
	@MinComboLoadRate.setter
	def MinComboLoadRate(self, value):
		self._set_attribute('minComboLoadRate', value)

	@property
	def MinFpsRate(self):
		"""DEPRECATED The rate at which minimum frames are sent per second.

		Returns:
			number
		"""
		return self._get_attribute('minFpsRate')
	@MinFpsRate.setter
	def MinFpsRate(self, value):
		self._set_attribute('minFpsRate', value)

	@property
	def MinIncrementFrameSize(self):
		"""DEPRECATED The minimum incremental value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('minIncrementFrameSize')
	@MinIncrementFrameSize.setter
	def MinIncrementFrameSize(self, value):
		self._set_attribute('minIncrementFrameSize', value)

	@property
	def MinKbpsRate(self):
		"""DEPRECATED The rate at which minimum frames are sent per kbps.

		Returns:
			number
		"""
		return self._get_attribute('minKbpsRate')
	@MinKbpsRate.setter
	def MinKbpsRate(self, value):
		self._set_attribute('minKbpsRate', value)

	@property
	def MinQuickSearchLoadRate(self):
		"""DEPRECATED Sets the minum Quick Search load rate

		Returns:
			number
		"""
		return self._get_attribute('minQuickSearchLoadRate')
	@MinQuickSearchLoadRate.setter
	def MinQuickSearchLoadRate(self, value):
		self._set_attribute('minQuickSearchLoadRate', value)

	@property
	def MinRandomFrameSize(self):
		"""DEPRECATED The minimum random frame size to be sent.

		Returns:
			number
		"""
		return self._get_attribute('minRandomFrameSize')
	@MinRandomFrameSize.setter
	def MinRandomFrameSize(self, value):
		self._set_attribute('minRandomFrameSize', value)

	@property
	def Numtrials(self):
		"""DEPRECATED Defines how many times each frame size will be tested.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def PercentMaxRate(self):
		"""DEPRECATED The percentage of the maximum rate that is specified.

		Returns:
			number
		"""
		return self._get_attribute('percentMaxRate')
	@PercentMaxRate.setter
	def PercentMaxRate(self, value):
		self._set_attribute('percentMaxRate', value)

	@property
	def PortDelayEnabled(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('portDelayEnabled')
	@PortDelayEnabled.setter
	def PortDelayEnabled(self, value):
		self._set_attribute('portDelayEnabled', value)

	@property
	def PortDelayUnit(self):
		"""DEPRECATED Sets the port delay unit in which it will be measured

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('portDelayUnit')
	@PortDelayUnit.setter
	def PortDelayUnit(self, value):
		self._set_attribute('portDelayUnit', value)

	@property
	def PortDelayValue(self):
		"""DEPRECATED Sets the port delay value

		Returns:
			number
		"""
		return self._get_attribute('portDelayValue')
	@PortDelayValue.setter
	def PortDelayValue(self, value):
		self._set_attribute('portDelayValue', value)

	@property
	def ProtocolItem(self):
		"""DEPRECATED Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def QuickSearchFrameLossUnit(self):
		"""DEPRECATED Sets the quick search frame loss unit

		Returns:
			str(%)
		"""
		return self._get_attribute('quickSearchFrameLossUnit')
	@QuickSearchFrameLossUnit.setter
	def QuickSearchFrameLossUnit(self, value):
		self._set_attribute('quickSearchFrameLossUnit', value)

	@property
	def QuickSearchLoadUnit(self):
		"""DEPRECATED Sets the quick search load unit

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('quickSearchLoadUnit')
	@QuickSearchLoadUnit.setter
	def QuickSearchLoadUnit(self, value):
		self._set_attribute('quickSearchLoadUnit', value)

	@property
	def QuickSearchResolution(self):
		"""DEPRECATED Sets the quick search resolution

		Returns:
			number
		"""
		return self._get_attribute('quickSearchResolution')
	@QuickSearchResolution.setter
	def QuickSearchResolution(self, value):
		self._set_attribute('quickSearchResolution', value)

	@property
	def QuickSearchSearchType(self):
		"""DEPRECATED Sets the quick search type

		Returns:
			str(linear|perFlow|perPort|perTrafficItem)
		"""
		return self._get_attribute('quickSearchSearchType')
	@QuickSearchSearchType.setter
	def QuickSearchSearchType(self, value):
		self._set_attribute('quickSearchSearchType', value)

	@property
	def QuickSearchTolerance(self):
		"""DEPRECATED Sets the quick search tolerance

		Returns:
			number
		"""
		return self._get_attribute('quickSearchTolerance')
	@QuickSearchTolerance.setter
	def QuickSearchTolerance(self, value):
		self._set_attribute('quickSearchTolerance', value)

	@property
	def RateSelect(self):
		"""DEPRECATED It selects the rate value of the protocol.

		Returns:
			str(fpsRate|kbpsRate|percentMaxRate)
		"""
		return self._get_attribute('rateSelect')
	@RateSelect.setter
	def RateSelect(self, value):
		self._set_attribute('rateSelect', value)

	@property
	def ReportSequenceError(self):
		"""DEPRECATED Reports sequence errors in the test result.

		Returns:
			bool
		"""
		return self._get_attribute('reportSequenceError')
	@ReportSequenceError.setter
	def ReportSequenceError(self, value):
		self._set_attribute('reportSequenceError', value)

	@property
	def ReportTputRateUnit(self):
		"""DEPRECATED The report throughput rate.

		Returns:
			str(gbps|gBps|kbps|kBps|mbps|mBps)
		"""
		return self._get_attribute('reportTputRateUnit')
	@ReportTputRateUnit.setter
	def ReportTputRateUnit(self, value):
		self._set_attribute('reportTputRateUnit', value)

	@property
	def Resolution(self):
		"""DEPRECATED Specifies the resolution of the iteration. The difference between the real rate transmission in two consecutive iterations, expressed as a percentage, is compared with the resolution value. When the difference is smaller than the value specified for the resolution, the test stops.

		Returns:
			number
		"""
		return self._get_attribute('resolution')
	@Resolution.setter
	def Resolution(self, value):
		self._set_attribute('resolution', value)

	@property
	def Rfc2889ordering(self):
		"""DEPRECATED Enables ordering.

		Returns:
			str(noOrdering|unchanged|val2889Ordering)
		"""
		return self._get_attribute('rfc2889ordering')
	@Rfc2889ordering.setter
	def Rfc2889ordering(self, value):
		self._set_attribute('rfc2889ordering', value)

	@property
	def SendFullyMeshed(self):
		"""DEPRECATED Indicates the source group mapping type used for sending data.

		Returns:
			bool
		"""
		return self._get_attribute('sendFullyMeshed')
	@SendFullyMeshed.setter
	def SendFullyMeshed(self, value):
		self._set_attribute('sendFullyMeshed', value)

	@property
	def ShowDetailedBinaryResults(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('showDetailedBinaryResults')
	@ShowDetailedBinaryResults.setter
	def ShowDetailedBinaryResults(self, value):
		self._set_attribute('showDetailedBinaryResults', value)

	@property
	def StepComboLoadRate(self):
		"""DEPRECATED The step rate of the binary algorithm for Combo Load Type.

		Returns:
			number
		"""
		return self._get_attribute('stepComboLoadRate')
	@StepComboLoadRate.setter
	def StepComboLoadRate(self, value):
		self._set_attribute('stepComboLoadRate', value)

	@property
	def StepFrameLossUnit(self):
		"""DEPRECATED The step frame loss unit.

		Returns:
			str(%|frames)
		"""
		return self._get_attribute('stepFrameLossUnit')
	@StepFrameLossUnit.setter
	def StepFrameLossUnit(self, value):
		self._set_attribute('stepFrameLossUnit', value)

	@property
	def StepIncrementFrameSize(self):
		"""DEPRECATED The incremental step value of the frame size.

		Returns:
			number
		"""
		return self._get_attribute('stepIncrementFrameSize')
	@StepIncrementFrameSize.setter
	def StepIncrementFrameSize(self, value):
		self._set_attribute('stepIncrementFrameSize', value)

	@property
	def StepLoadUnit(self):
		"""DEPRECATED The step load unit.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('stepLoadUnit')
	@StepLoadUnit.setter
	def StepLoadUnit(self, value):
		self._set_attribute('stepLoadUnit', value)

	@property
	def StepStepLoadRate(self):
		"""DEPRECATED The step rate of the binary algorithm.

		Returns:
			number
		"""
		return self._get_attribute('stepStepLoadRate')
	@StepStepLoadRate.setter
	def StepStepLoadRate(self, value):
		self._set_attribute('stepStepLoadRate', value)

	@property
	def StepTolerance(self):
		"""DEPRECATED The value of the tolerance level for Step Load Type.

		Returns:
			number
		"""
		return self._get_attribute('stepTolerance')
	@StepTolerance.setter
	def StepTolerance(self, value):
		self._set_attribute('stepTolerance', value)

	@property
	def SupportedTrafficTypes(self):
		"""DEPRECATED The traffic types supported.

		Returns:
			str
		"""
		return self._get_attribute('supportedTrafficTypes')
	@SupportedTrafficTypes.setter
	def SupportedTrafficTypes(self, value):
		self._set_attribute('supportedTrafficTypes', value)

	@property
	def Tolerance(self):
		"""DEPRECATED The level of acceptable threshold.

		Returns:
			number
		"""
		return self._get_attribute('tolerance')
	@Tolerance.setter
	def Tolerance(self, value):
		self._set_attribute('tolerance', value)

	@property
	def TrafficType(self):
		"""DEPRECATED It signifies the traffic type.

		Returns:
			str(burstyLoading|constantLoading)
		"""
		return self._get_attribute('trafficType')
	@TrafficType.setter
	def TrafficType(self, value):
		self._set_attribute('trafficType', value)

	@property
	def TxDelay(self):
		"""DEPRECATED Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	@property
	def UsePercentOffsets(self):
		"""DEPRECATED Uses percentage offset value.

		Returns:
			bool
		"""
		return self._get_attribute('usePercentOffsets')
	@UsePercentOffsets.setter
	def UsePercentOffsets(self, value):
		self._set_attribute('usePercentOffsets', value)

	def update(self, BinaryBackoff=None, BinaryFrameLossUnit=None, BinaryLoadUnit=None, BinaryResolution=None, BinarySearchType=None, BinaryTolerance=None, BurstSize=None, CalculateJitter=None, CalculateLatency=None, ComboBackoff=None, ComboFrameLossUnit=None, ComboLoadUnit=None, ComboResolution=None, ComboTolerance=None, CountRandomFrameSize=None, CustomLoadUnit=None, DelayAfterTransmit=None, DetailedResultsEnabled=None, Duration=None, EnableDataIntegrity=None, EnableExtraIterations=None, EnableFastConvergence=None, EnableLayer1Rate=None, EnableMinFrameSize=None, EnableOldStatsForReef=None, ExtraIterationOffsets=None, FastConvergenceDuration=None, FastConvergenceThreshold=None, ForceRegenerate=None, FrameLossUnit=None, FrameOrderingByRfc2889=None, FrameSizeMode=None, FramesPerBurstGap=None, Framesize=None, FramesizeList=None, Gap=None, GenerateTrackingOptionAggregationFiles=None, InitialBinaryLoadRate=None, InitialComboLoadRate=None, InitialStepLoadRate=None, LatencyBins=None, LatencyBinsEnabled=None, LatencyType=None, LoadRateList=None, LoadType=None, MapType=None, MaxBinaryLoadRate=None, MaxComboLoadRate=None, MaxIncrementFrameSize=None, MaxQuickSearchLoadRate=None, MaxRandomFrameSize=None, MaxStepLoadRate=None, MinBinaryLoadRate=None, MinComboLoadRate=None, MinFpsRate=None, MinIncrementFrameSize=None, MinKbpsRate=None, MinQuickSearchLoadRate=None, MinRandomFrameSize=None, Numtrials=None, PercentMaxRate=None, PortDelayEnabled=None, PortDelayUnit=None, PortDelayValue=None, ProtocolItem=None, QuickSearchFrameLossUnit=None, QuickSearchLoadUnit=None, QuickSearchResolution=None, QuickSearchSearchType=None, QuickSearchTolerance=None, RateSelect=None, ReportSequenceError=None, ReportTputRateUnit=None, Resolution=None, Rfc2889ordering=None, SendFullyMeshed=None, ShowDetailedBinaryResults=None, StepComboLoadRate=None, StepFrameLossUnit=None, StepIncrementFrameSize=None, StepLoadUnit=None, StepStepLoadRate=None, StepTolerance=None, SupportedTrafficTypes=None, Tolerance=None, TrafficType=None, TxDelay=None, UsePercentOffsets=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			BinaryBackoff (number): The percentage to be applied to the search interval through which the next iterations rate is obtained.
			BinaryFrameLossUnit (str(%|frames)): The binary frame loss unit.
			BinaryLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The binary load unit.
			BinaryResolution (number): The resolution of the iteration during a binary search.
			BinarySearchType (str(linear|perFlow|perPort)): The binary search type.
			BinaryTolerance (number): The percentage of frame loss that is acceptable in order for an iteration to be considered successful during a binary search.
			BurstSize (number): It signifies the burst size of the protocol.
			CalculateJitter (bool): If true, enables jitter calculation.
			CalculateLatency (bool): If true, enables latency calculation.
			ComboBackoff (number): The percentage to be applied to the search interval through which the next iterations rate is obtained, for Combo Load Type.
			ComboFrameLossUnit (str(%|frames)): The combo frame loss unit.
			ComboLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The combo Load Unit.
			ComboResolution (number): The resolution of the iteration for Combo Load Type.
			ComboTolerance (number): The value of the tolerance level for Combo Load Type.
			CountRandomFrameSize (number): If true, randomly counts the frame size.
			CustomLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The custom load unit.
			DelayAfterTransmit (number): Specifies the amount of delay after every transmit.
			DetailedResultsEnabled (bool): 
			Duration (number): The duration of the test in hours, which is used to calculate the number of framesto transmit.
			EnableDataIntegrity (bool): If true, enables data integrity test.
			EnableExtraIterations (bool): If true, enables the tracking option in aggregation files.
			EnableFastConvergence (bool): If true, enables fast convergence.
			EnableLayer1Rate (bool): NOT DEFINED
			EnableMinFrameSize (bool): If true, enables minimum frame size.
			EnableOldStatsForReef (bool): Enables old statistics for reef.
			ExtraIterationOffsets (str): Sets extra iteration offset values.
			FastConvergenceDuration (number): sec
			FastConvergenceThreshold (number): If true, enables fast convergence threshold value.
			ForceRegenerate (bool): Initiates a forced regeneration.
			FrameLossUnit (str): The frame loss unit.
			FrameOrderingByRfc2889 (bool): If true, indicates frame ordering by Rfc2889.
			FrameSizeMode (str(custom|customlist|increment|random)): This attribute is the frame size mode for the Quad Gaussian.
			FramesPerBurstGap (number): It signifies the frames per burst gap.
			Framesize (number): Bytes
			FramesizeList (list(str)): List containing the frame sizes used in the test.
			Gap (number): Inter-frame gap.
			GenerateTrackingOptionAggregationFiles (bool): If true, enables the tracking option in aggregation files.
			InitialBinaryLoadRate (number): The load rate used in the first iteration for each frame size during a binary search.
			InitialComboLoadRate (number): The initial value of the load rate for Combo Load Type.
			InitialStepLoadRate (number): The initial value of the load rate for Step Load Type.
			LatencyBins (str): Sets the latency bins statistics
			LatencyBinsEnabled (bool): Enables the latency bins statistics
			LatencyType (str(cutThrough|storeForward)): The type of latency.
			LoadRateList (str): The list of Load Rate.
			LoadType (str(binary|combo|custom|quickSearch|step|unchanged)): The type of load.
			MapType (str): The POS traffic map type.
			MaxBinaryLoadRate (number): The lower bound of the iteration rates for each frame size during a binary search.
			MaxComboLoadRate (number): The maximum value of the load rate Combo Load Type.
			MaxIncrementFrameSize (number): The maximum incremental value of the frame size.
			MaxQuickSearchLoadRate (number): Sets the maximum QuickSearch load rate
			MaxRandomFrameSize (number): The maximum random frame size to be sent.
			MaxStepLoadRate (number): The maximum value of the load rate Step Load Type.
			MinBinaryLoadRate (number): The lower bound of the iteration rates for each frame size during a binary search.
			MinComboLoadRate (number): The minimum value of the load rate Combo Load Type.
			MinFpsRate (number): The rate at which minimum frames are sent per second.
			MinIncrementFrameSize (number): The minimum incremental value of the frame size.
			MinKbpsRate (number): The rate at which minimum frames are sent per kbps.
			MinQuickSearchLoadRate (number): Sets the minum Quick Search load rate
			MinRandomFrameSize (number): The minimum random frame size to be sent.
			Numtrials (number): Defines how many times each frame size will be tested.
			PercentMaxRate (number): The percentage of the maximum rate that is specified.
			PortDelayEnabled (bool): NOT DEFINED
			PortDelayUnit (str(bytes|nanoseconds)): Sets the port delay unit in which it will be measured
			PortDelayValue (number): Sets the port delay value
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			QuickSearchFrameLossUnit (str(%)): Sets the quick search frame loss unit
			QuickSearchLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): Sets the quick search load unit
			QuickSearchResolution (number): Sets the quick search resolution
			QuickSearchSearchType (str(linear|perFlow|perPort|perTrafficItem)): Sets the quick search type
			QuickSearchTolerance (number): Sets the quick search tolerance
			RateSelect (str(fpsRate|kbpsRate|percentMaxRate)): It selects the rate value of the protocol.
			ReportSequenceError (bool): Reports sequence errors in the test result.
			ReportTputRateUnit (str(gbps|gBps|kbps|kBps|mbps|mBps)): The report throughput rate.
			Resolution (number): Specifies the resolution of the iteration. The difference between the real rate transmission in two consecutive iterations, expressed as a percentage, is compared with the resolution value. When the difference is smaller than the value specified for the resolution, the test stops.
			Rfc2889ordering (str(noOrdering|unchanged|val2889Ordering)): Enables ordering.
			SendFullyMeshed (bool): Indicates the source group mapping type used for sending data.
			ShowDetailedBinaryResults (bool): NOT DEFINED
			StepComboLoadRate (number): The step rate of the binary algorithm for Combo Load Type.
			StepFrameLossUnit (str(%|frames)): The step frame loss unit.
			StepIncrementFrameSize (number): The incremental step value of the frame size.
			StepLoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The step load unit.
			StepStepLoadRate (number): The step rate of the binary algorithm.
			StepTolerance (number): The value of the tolerance level for Step Load Type.
			SupportedTrafficTypes (str): The traffic types supported.
			Tolerance (number): The level of acceptable threshold.
			TrafficType (str(burstyLoading|constantLoading)): It signifies the traffic type.
			TxDelay (number): Specifies the amount of delay after every transmit.
			UsePercentOffsets (bool): Uses percentage offset value.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PimV6CandidateRPsList(Base):
	"""The PimV6CandidateRPsList class encapsulates a required pimV6CandidateRPsList node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PimV6CandidateRPsList property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'pimV6CandidateRPsList'

	def __init__(self, parent):
		super(PimV6CandidateRPsList, self).__init__(parent)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def AdvertisementHoldTime(self):
		"""Time interval between two consecutive Candidate RP advertisements

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('advertisementHoldTime')

	@property
	def BackOffInterval(self):
		"""The back-off time interval for the C-RP-Adv messages

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('backOffInterval')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def CrpAddress(self):
		"""Start address of the set of candidate RPs to be simulated

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('crpAddress')

	@property
	def CrpAddressCount(self):
		"""Total number of Candidate RPs to be simulated starting from C-RP address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('crpAddressCount')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def GroupAddress(self):
		"""Starting group address of the group range for which the candidate RP will advertise candidacy

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('groupAddress')

	@property
	def GroupCount(self):
		"""Number of groups in the range

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('groupCount')

	@property
	def GroupMaskLen(self):
		"""Mask width (prefix length in bits) for the group range

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('groupMaskLen')

	@property
	def LocalRouterId(self):
		"""Router ID

		Returns:
			list(str)
		"""
		return self._get_attribute('localRouterId')

	@property
	def MeshingType(self):
		"""It indicates if the mappings for groups and RP addresses are Fully-Meshed or One-To-One. One-to-one indicates that for each group only one RP shall be sent regardless of the RP count. Full meshed means for each group all RPs shall be advertised for candidacy which is essentially a (group to rp) mapping.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('meshingType')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def PeriodicAdvertisementInterval(self):
		"""Rate controlling variable indicating how many C-RP-Adv messages can be sent in the specified time interval

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('periodicAdvertisementInterval')

	@property
	def Priority(self):
		"""Value of priority to be sent in candidate RP advertisement

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('priority')

	@property
	def PriorityChangeInterval(self):
		"""Time interval after which priority of all the RPs get changed

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('priorityChangeInterval')

	@property
	def PriorityType(self):
		"""It indicates the type of priority to be held by the candidate RPs

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('priorityType')

	@property
	def Status(self):
		"""Status

		Returns:
			list(str[none|notStarted|started])
		"""
		return self._get_attribute('status')

	@property
	def TriggeredCrpMessageCount(self):
		"""The number of times C-RP advertisements is sent to the newly elected Bootstrap Routers

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('triggeredCrpMessageCount')

	def update(self, Name=None):
		"""Updates a child instance of pimV6CandidateRPsList on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, Active=None, AdvertisementHoldTime=None, BackOffInterval=None, CrpAddress=None, CrpAddressCount=None, GroupAddress=None, GroupCount=None, GroupMaskLen=None, MeshingType=None, PeriodicAdvertisementInterval=None, Priority=None, PriorityChangeInterval=None, PriorityType=None, TriggeredCrpMessageCount=None):
		"""Base class infrastructure that gets a list of pimV6CandidateRPsList device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			AdvertisementHoldTime (str): optional regex of advertisementHoldTime
			BackOffInterval (str): optional regex of backOffInterval
			CrpAddress (str): optional regex of crpAddress
			CrpAddressCount (str): optional regex of crpAddressCount
			GroupAddress (str): optional regex of groupAddress
			GroupCount (str): optional regex of groupCount
			GroupMaskLen (str): optional regex of groupMaskLen
			MeshingType (str): optional regex of meshingType
			PeriodicAdvertisementInterval (str): optional regex of periodicAdvertisementInterval
			Priority (str): optional regex of priority
			PriorityChangeInterval (str): optional regex of priorityChangeInterval
			PriorityType (str): optional regex of priorityType
			TriggeredCrpMessageCount (str): optional regex of triggeredCrpMessageCount

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Activate Candidate RP

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		start(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Deactivate Candidate RP

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stop(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Statistic(Base):
	"""The Statistic class encapsulates a user managed statistic node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Statistic property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'statistic'

	def __init__(self, parent):
		super(Statistic, self).__init__(parent)

	@property
	def Enable(self):
		"""Enable/Disable monitoring for the current statistic.

		Returns:
			bool
		"""
		return self._get_attribute('enable')
	@Enable.setter
	def Enable(self, value):
		self._set_attribute('enable', value)

	@property
	def Name(self):
		"""The name of the statistic that is being monitored.

		Returns:
			str
		"""
		return self._get_attribute('name')

	@property
	def Notes(self):
		"""Additional notes that explain what is being monitored for this statistic.

		Returns:
			str
		"""
		return self._get_attribute('notes')

	@property
	def Operator(self):
		"""The operator that is being used to compare the actual value of the statistic with the configured threshold.

		Returns:
			str
		"""
		return self._get_attribute('operator')

	@property
	def Unit(self):
		"""The measurement unit being used for this statistic.

		Returns:
			str
		"""
		return self._get_attribute('unit')

	@property
	def Value(self):
		"""The threshold for the current statistic. Exceeding this value will trigger a warning if monitoring is enabled for this statistic.

		Returns:
			number
		"""
		return self._get_attribute('value')
	@Value.setter
	def Value(self, value):
		self._set_attribute('value', value)

	def update(self, Enable=None, Value=None):
		"""Updates a child instance of statistic on the server.

		Args:
			Enable (bool): Enable/Disable monitoring for the current statistic.
			Value (number): The threshold for the current statistic. Exceeding this value will trigger a warning if monitoring is enabled for this statistic.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Enable=None, Value=None):
		"""Adds a new statistic node on the server and retrieves it in this instance.

		Args:
			Enable (bool): Enable/Disable monitoring for the current statistic.
			Value (number): The threshold for the current statistic. Exceeding this value will trigger a warning if monitoring is enabled for this statistic.

		Returns:
			self: This instance with all currently retrieved statistic data using find and the newly added statistic data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the statistic data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Enable=None, Name=None, Notes=None, Operator=None, Unit=None, Value=None):
		"""Finds and retrieves statistic data from the server.

		All named parameters support regex and can be used to selectively retrieve statistic data from the server.
		By default the find method takes no parameters and will retrieve all statistic data from the server.

		Args:
			Enable (bool): Enable/Disable monitoring for the current statistic.
			Name (str): The name of the statistic that is being monitored.
			Notes (str): Additional notes that explain what is being monitored for this statistic.
			Operator (str): The operator that is being used to compare the actual value of the statistic with the configured threshold.
			Unit (str): The measurement unit being used for this statistic.
			Value (number): The threshold for the current statistic. Exceeding this value will trigger a warning if monitoring is enabled for this statistic.

		Returns:
			self: This instance with matching statistic data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of statistic data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the statistic data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class CustomTopologySpbNodeIsidRange(Base):
	"""The CustomTopologySpbNodeIsidRange class encapsulates a user managed customTopologySpbNodeIsidRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the CustomTopologySpbNodeIsidRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'customTopologySpbNodeIsidRange'

	def __init__(self, parent):
		super(CustomTopologySpbNodeIsidRange, self).__init__(parent)

	@property
	def CMacAddressCount(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('cMacAddressCount')
	@CMacAddressCount.setter
	def CMacAddressCount(self, value):
		self._set_attribute('cMacAddressCount', value)

	@property
	def CMacAddressStep(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('cMacAddressStep')
	@CMacAddressStep.setter
	def CMacAddressStep(self, value):
		self._set_attribute('cMacAddressStep', value)

	@property
	def EnableIsid(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableIsid')
	@EnableIsid.setter
	def EnableIsid(self, value):
		self._set_attribute('enableIsid', value)

	@property
	def InterNodeCmacAddress(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('interNodeCmacAddress')
	@InterNodeCmacAddress.setter
	def InterNodeCmacAddress(self, value):
		self._set_attribute('interNodeCmacAddress', value)

	@property
	def InterNodeCvlan(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('interNodeCvlan')
	@InterNodeCvlan.setter
	def InterNodeCvlan(self, value):
		self._set_attribute('interNodeCvlan', value)

	@property
	def InterNodeIsIdIncrement(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('interNodeIsIdIncrement')
	@InterNodeIsIdIncrement.setter
	def InterNodeIsIdIncrement(self, value):
		self._set_attribute('interNodeIsIdIncrement', value)

	@property
	def InterNodeSvlan(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('interNodeSvlan')
	@InterNodeSvlan.setter
	def InterNodeSvlan(self, value):
		self._set_attribute('interNodeSvlan', value)

	@property
	def Isid(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('isid')
	@Isid.setter
	def Isid(self, value):
		self._set_attribute('isid', value)

	@property
	def RBit(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('rBit')
	@RBit.setter
	def RBit(self, value):
		self._set_attribute('rBit', value)

	@property
	def StartCmacAddress(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('startCmacAddress')
	@StartCmacAddress.setter
	def StartCmacAddress(self, value):
		self._set_attribute('startCmacAddress', value)

	@property
	def StartCvlan(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('startCvlan')
	@StartCvlan.setter
	def StartCvlan(self, value):
		self._set_attribute('startCvlan', value)

	@property
	def StartSvlan(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('startSvlan')
	@StartSvlan.setter
	def StartSvlan(self, value):
		self._set_attribute('startSvlan', value)

	@property
	def TBit(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('tBit')
	@TBit.setter
	def TBit(self, value):
		self._set_attribute('tBit', value)

	@property
	def TransmissionType(self):
		"""NOT DEFINED

		Returns:
			str(unicast|multicast)
		"""
		return self._get_attribute('transmissionType')
	@TransmissionType.setter
	def TransmissionType(self, value):
		self._set_attribute('transmissionType', value)

	@property
	def VlanType(self):
		"""NOT DEFINED

		Returns:
			str(singleVlan|stackedVlanQinQ)
		"""
		return self._get_attribute('vlanType')
	@VlanType.setter
	def VlanType(self, value):
		self._set_attribute('vlanType', value)

	def update(self, CMacAddressCount=None, CMacAddressStep=None, EnableIsid=None, InterNodeCmacAddress=None, InterNodeCvlan=None, InterNodeIsIdIncrement=None, InterNodeSvlan=None, Isid=None, RBit=None, StartCmacAddress=None, StartCvlan=None, StartSvlan=None, TBit=None, TransmissionType=None, VlanType=None):
		"""Updates a child instance of customTopologySpbNodeIsidRange on the server.

		Args:
			CMacAddressCount (number): NOT DEFINED
			CMacAddressStep (str): NOT DEFINED
			EnableIsid (bool): NOT DEFINED
			InterNodeCmacAddress (str): NOT DEFINED
			InterNodeCvlan (number): NOT DEFINED
			InterNodeIsIdIncrement (number): NOT DEFINED
			InterNodeSvlan (number): NOT DEFINED
			Isid (number): NOT DEFINED
			RBit (bool): NOT DEFINED
			StartCmacAddress (str): NOT DEFINED
			StartCvlan (number): NOT DEFINED
			StartSvlan (number): NOT DEFINED
			TBit (bool): NOT DEFINED
			TransmissionType (str(unicast|multicast)): NOT DEFINED
			VlanType (str(singleVlan|stackedVlanQinQ)): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, CMacAddressCount=None, CMacAddressStep=None, EnableIsid=None, InterNodeCmacAddress=None, InterNodeCvlan=None, InterNodeIsIdIncrement=None, InterNodeSvlan=None, Isid=None, RBit=None, StartCmacAddress=None, StartCvlan=None, StartSvlan=None, TBit=None, TransmissionType=None, VlanType=None):
		"""Adds a new customTopologySpbNodeIsidRange node on the server and retrieves it in this instance.

		Args:
			CMacAddressCount (number): NOT DEFINED
			CMacAddressStep (str): NOT DEFINED
			EnableIsid (bool): NOT DEFINED
			InterNodeCmacAddress (str): NOT DEFINED
			InterNodeCvlan (number): NOT DEFINED
			InterNodeIsIdIncrement (number): NOT DEFINED
			InterNodeSvlan (number): NOT DEFINED
			Isid (number): NOT DEFINED
			RBit (bool): NOT DEFINED
			StartCmacAddress (str): NOT DEFINED
			StartCvlan (number): NOT DEFINED
			StartSvlan (number): NOT DEFINED
			TBit (bool): NOT DEFINED
			TransmissionType (str(unicast|multicast)): NOT DEFINED
			VlanType (str(singleVlan|stackedVlanQinQ)): NOT DEFINED

		Returns:
			self: This instance with all currently retrieved customTopologySpbNodeIsidRange data using find and the newly added customTopologySpbNodeIsidRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the customTopologySpbNodeIsidRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, CMacAddressCount=None, CMacAddressStep=None, EnableIsid=None, InterNodeCmacAddress=None, InterNodeCvlan=None, InterNodeIsIdIncrement=None, InterNodeSvlan=None, Isid=None, RBit=None, StartCmacAddress=None, StartCvlan=None, StartSvlan=None, TBit=None, TransmissionType=None, VlanType=None):
		"""Finds and retrieves customTopologySpbNodeIsidRange data from the server.

		All named parameters support regex and can be used to selectively retrieve customTopologySpbNodeIsidRange data from the server.
		By default the find method takes no parameters and will retrieve all customTopologySpbNodeIsidRange data from the server.

		Args:
			CMacAddressCount (number): NOT DEFINED
			CMacAddressStep (str): NOT DEFINED
			EnableIsid (bool): NOT DEFINED
			InterNodeCmacAddress (str): NOT DEFINED
			InterNodeCvlan (number): NOT DEFINED
			InterNodeIsIdIncrement (number): NOT DEFINED
			InterNodeSvlan (number): NOT DEFINED
			Isid (number): NOT DEFINED
			RBit (bool): NOT DEFINED
			StartCmacAddress (str): NOT DEFINED
			StartCvlan (number): NOT DEFINED
			StartSvlan (number): NOT DEFINED
			TBit (bool): NOT DEFINED
			TransmissionType (str(unicast|multicast)): NOT DEFINED
			VlanType (str(singleVlan|stackedVlanQinQ)): NOT DEFINED

		Returns:
			self: This instance with matching customTopologySpbNodeIsidRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of customTopologySpbNodeIsidRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the customTopologySpbNodeIsidRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ixnetwork(Base):
	"""The Ixnetwork class encapsulates a system managed / node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ixnetwork property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'ixnetwork'

	def __init__(self, parent):
		super(Ixnetwork, self).__init__(parent)

	@property
	def AvailableHardware(self):
		"""An instance of the AvailableHardware class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.availablehardware.availablehardware.AvailableHardware)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.availablehardware.availablehardware import AvailableHardware
		return AvailableHardware(self)._select()

	@property
	def Globals(self):
		"""An instance of the Globals class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.globals.Globals)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.globals import Globals
		return Globals(self)._select()

	@property
	def Impairment(self):
		"""An instance of the Impairment class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.impairment.impairment.Impairment)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.impairment.impairment import Impairment
		return Impairment(self)._select()

	@property
	def Lag(self):
		"""An instance of the Lag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.lag.lag.Lag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.lag.lag import Lag
		return Lag(self)

	@property
	def QuickTest(self):
		"""An instance of the QuickTest class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.quicktest.quicktest.QuickTest)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.quicktest.quicktest import QuickTest
		return QuickTest(self)._select()

	@property
	def ResourceManager(self):
		"""An instance of the ResourceManager class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.resourcemanager.resourcemanager.ResourceManager)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.resourcemanager.resourcemanager import ResourceManager
		return ResourceManager(self)._select()

	@property
	def Statistics(self):
		"""An instance of the Statistics class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.statistics.Statistics)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.statistics import Statistics
		return Statistics(self)._select()

	@property
	def Timeline(self):
		"""An instance of the Timeline class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.timeline.timeline.Timeline)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.timeline.timeline import Timeline
		return Timeline(self)._select()

	@property
	def Topology(self):
		"""An instance of the Topology class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.topology.Topology)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.topology import Topology
		return Topology(self)

	@property
	def Traffic(self):
		"""An instance of the Traffic class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.traffic.Traffic)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.traffic import Traffic
		return Traffic(self)._select()

	@property
	def Vport(self):
		"""An instance of the Vport class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.vport.Vport)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.vport import Vport
		return Vport(self)

	def ApplyITWizardConfiguration(self, *args, **kwargs):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the first Quick Test found in the current configuration.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		applyITWizardConfiguration()

		applyITWizardConfiguration(TestName:string)
			Args:
				args[0] is TestName (str): The name of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def ApplyL1Blocking(self):
		"""Executes the applyL1Blocking operation on the server.

		Apply L1 blocking.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('applyL1Blocking', payload=payload, response_object=None)

	def AssignPorts(self, *args, **kwargs):
		"""Executes the assignPorts operation on the server.

		Assign hardware ports to virtual ports.

		assignPorts(Arg1:list, Arg2:list, Arg3:list, Arg4:bool)list
			Args:
				args[0] is Arg1 (list(dict(arg1:str,arg2:str,arg3:str))): A list of chassis, card, port combinations to include.
				args[1] is Arg2 (list(dict(arg1:str,arg2:str,arg3:str))): A list of chassis, card, port combinations to exclude.
				args[2] is Arg3 (list(str[None|/api/v1/sessions/1/ixnetwork/vport])): A list of virtual port object references that hardware ports will be attached to.
				args[3] is Arg4 (bool): If true, it will clear ownership on the hardware ports.

			Returns:
				list(str[None|/api/v1/sessions/1/ixnetwork/vport]): Returns a list of virtual port object references that were successfully connected.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('assignPorts', payload=payload, response_object=None)

	def ClearAppLibraryStats(self):
		"""Executes the clearAppLibraryStats operation on the server.

		Clears the statistics published by AppLibrary.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('clearAppLibraryStats', payload=payload, response_object=None)

	def ClearCardOwnershipById(self, *args, **kwargs):
		"""Executes the clearCardOwnershipById operation on the server.

		Clear ownership on all ports from the given IxVM card.

		clearCardOwnershipById(Arg1:string)number
			Args:
				args[0] is Arg1 (str): The card ID.

			Returns:
				number: Returns the card ID.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearCardOwnershipById', payload=payload, response_object=None)

	def ClearCPDPStats(self):
		"""Executes the clearCPDPStats operation on the server.

		Clear control pland and data plane statistics.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('clearCPDPStats', payload=payload, response_object=None)

	def ClearPortsAndTrafficStats(self, *args, **kwargs):
		"""Executes the clearPortsAndTrafficStats operation on the server.

		The command to clear the existing port and traffic statistics.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		clearPortsAndTrafficStats()

		clearPortsAndTrafficStats(Arg1:list)
			Args:
				args[0] is Arg1 (list(str[waitForPortStatsRefresh|waitForTrafficStatsRefresh])): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearPortsAndTrafficStats', payload=payload, response_object=None)

	def ClearProtocolStats(self):
		"""Executes the clearProtocolStats operation on the server.

		Clear the protocol statistics.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('clearProtocolStats', payload=payload, response_object=None)

	def ClearStats(self, *args, **kwargs):
		"""Executes the clearStats operation on the server.

		The command to clear the existing statistics.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		clearStats()

		clearStats(Arg1:list)
			Args:
				args[0] is Arg1 (list(str[waitForPortStatsRefresh|waitForTrafficStatsRefresh])): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearStats', payload=payload, response_object=None)

	def CloseAllTabs(self, *args, **kwargs):
		"""Executes the closeAllTabs operation on the server.

		This command closes all the captures if no parameter is specified; or a specific list of online captures

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		closeAllTabs()

		closeAllTabs(Arg1:list)
			Args:
				args[0] is Arg1 (list(str)): The list of capture names to be closed.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('closeAllTabs', payload=payload, response_object=None)

	def CollectLogs(self, *args, **kwargs):
		"""Executes the collectLogs operation on the server.

		This command collects all of the IxNetwork logs and puts them in a .zip file.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		collectLogs(Arg1:href)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.

		collectLogs(Arg1:href, Arg2:list)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.
				args[1] is Arg2 (list(str[currentInstance|specificProfile])): The instance to collect logs for.

		collectLogs(Arg1:href, Arg2:list, Arg3:string)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A valid output file handle from the ixNet writeTo command.
				args[1] is Arg2 (list(str[currentInstance|specificProfile])): A valid enum as specified by the restriction.
				args[2] is Arg3 (str): A string value.

		collectLogs(Arg1:href, Arg2:list, Arg3:string, Arg4:string)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A string value.
				args[1] is Arg2 (list(str[currentInstance|specificProfile])): An enum value indicating the item to collect logs for.
				args[2] is Arg3 (str): A string value.
				args[3] is Arg4 (str): A string value.

		collectLogs(Arg1:href, Arg2:list, Arg3:string, Arg4:string, Arg5:string)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A valid output file handle from the ixNet writeTo command.
				args[1] is Arg2 (list(str[currentInstance|specificProfile])): A valid enum as specified by the restriction.
				args[2] is Arg3 (str): A string value.
				args[3] is Arg4 (str): A string value.
				args[4] is Arg5 (str): A string value.

		collectLogs(Arg1:href, Arg2:string)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.
				args[1] is Arg2 (str): A string value.

		collectLogs(Arg1:href, Arg2:string, Arg3:string)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.
				args[1] is Arg2 (str): A string value.
				args[2] is Arg3 (str): A string value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('collectLogs', payload=payload, response_object=None)

	def ConnectCardById(self, *args, **kwargs):
		"""Executes the connectCardById operation on the server.

		Establish connection to the IxVM card.

		connectCardById(Arg1:string)number
			Args:
				args[0] is Arg1 (str): Card ID to which connection is required.

			Returns:
				number: Returns the connected card ID or error, if any.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('connectCardById', payload=payload, response_object=None)

	def ConnectToChassis(self, *args, **kwargs):
		"""Executes the connectToChassis operation on the server.

		Connect to a virtual chassis.

		connectToChassis(Arg1:string)
			Args:
				args[0] is Arg1 (str): The hostname or IP address of the chassis.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('connectToChassis', payload=payload, response_object=None)

	def CopyFile(self, *args, **kwargs):
		"""Executes the copyFile operation on the server.

		Copies from first stream into the second stream.

		copyFile(Arg1:href, Arg2:href)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): The source file for the copy operation. This stream must be readable.
				args[1] is Arg2 (obj(ixnetwork_restpy.files.Files)): The destination file for the copy operation. This stream must be writable.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('copyFile', payload=payload, response_object=None)

	def DisconnectCardById(self, *args, **kwargs):
		"""Executes the disconnectCardById operation on the server.

		Close connection to the IxVM card.

		disconnectCardById(Arg1:string)number
			Args:
				args[0] is Arg1 (str): The card ID.

			Returns:
				number: Returns the card ID.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('disconnectCardById', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		This report feature generates an integrated test report file.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('generateReport', payload=payload, response_object=None)

	def GetAggregatedDeviceGroupStatus(self):
		"""Executes the getAggregatedDeviceGroupStatus operation on the server.

			Returns:
				list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*],arg2:list[dict(arg1:str,arg2:number)])): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getAggregatedDeviceGroupStatus', payload=payload, response_object=None)

	def GetAllPorts(self):
		"""Executes the getAllPorts operation on the server.

		The command to get all the ports.

			Returns:
				str: A string with all the ports.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getAllPorts', payload=payload, response_object=None)

	def GetAvailableProtocolStats(self):
		"""Executes the getAvailableProtocolStats operation on the server.

		The command to get available protocol statistics.

			Returns:
				str: A string with all the legacy protocols statistics.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getAvailableProtocolStats', payload=payload, response_object=None)

	def GetAvailableSlotLicense(self, *args, **kwargs):
		"""Executes the getAvailableSlotLicense operation on the server.

		This exec returns number of AppLibrary Slot License avaibale for use in the chassis.

		getAvailableSlotLicense(Arg1:string)number
			Args:
				args[0] is Arg1 (str): The IPv4 address of the chassis.

			Returns:
				number: The number of AppLibrary Slot License available for use in the chassis.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getAvailableSlotLicense', payload=payload, response_object=None)

	def GetAvailableStatsForProtocol(self, *args, **kwargs):
		"""Executes the getAvailableStatsForProtocol operation on the server.

		The command to get available statistics for the protocol.

		getAvailableStatsForProtocol(Arg1:string)string
			Args:
				args[0] is Arg1 (str): Protocol name.

			Returns:
				str: A string with all the available statistics.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getAvailableStatsForProtocol', payload=payload, response_object=None)

	def GetAvailableStatsForSourceType(self, *args, **kwargs):
		"""Executes the getAvailableStatsForSourceType operation on the server.

		The command to get available statistics for the source type.

		getAvailableStatsForSourceType(Arg1:string)string
			Args:
				args[0] is Arg1 (str): Source type.

			Returns:
				str: A string with all the available statistics.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getAvailableStatsForSourceType', payload=payload, response_object=None)

	def GetConfiguredProtocols(self):
		"""Executes the getConfiguredProtocols operation on the server.

		The command to get the configured protocols.

			Returns:
				str: A list with all the protocols configured in the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getConfiguredProtocols', payload=payload, response_object=None)

	def GetConfiguredProtocolsForPort(self, *args, **kwargs):
		"""Executes the getConfiguredProtocolsForPort operation on the server.

		The command to get the configured protocols for the port.

		getConfiguredProtocolsForPort(Arg1:number)string
			Args:
				args[0] is Arg1 (number): Port ID.

			Returns:
				str: A string with all the available protocols configured on the port.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getConfiguredProtocolsForPort', payload=payload, response_object=None)

	def GetCsvColumnNames(self, *args, **kwargs):
		"""Executes the getCsvColumnNames operation on the server.

		getCsvColumnNames(Arg1:href)list
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): 

			Returns:
				list(str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getCsvColumnNames', payload=payload, response_object=None)

	def GetCurrentIxiaFileFormatTypeVersion(self):
		"""Executes the getCurrentIxiaFileFormatTypeVersion operation on the server.

		This command sets the current Ixia file format type version.

			Returns:
				number: Returns current Ixia file format type version.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getCurrentIxiaFileFormatTypeVersion', payload=payload, response_object=None)

	def GetDefaultSnapshotSettings(self):
		"""Executes the GetDefaultSnapshotSettings operation on the server.

		Gets the default snapshot settings.

			Returns:
				list(str): An array with settings.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('GetDefaultSnapshotSettings', payload=payload, response_object=None)

	def GetInstalledSlotLicenseCount(self, *args, **kwargs):
		"""Executes the getInstalledSlotLicenseCount operation on the server.

		This exec returns number of AppLibrary Slot License installed in the chassis.

		getInstalledSlotLicenseCount(Arg1:string)number
			Args:
				args[0] is Arg1 (str): The IPv4 address of the chassis.

			Returns:
				number: The number of AppLibrary Slot License installed in the chassis.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getInstalledSlotLicenseCount', payload=payload, response_object=None)

	def GetIntersectionPortsForProtocols(self, *args, **kwargs):
		"""Executes the getIntersectionPortsForProtocols operation on the server.

		The command to get intersection ports for the protocols.

		getIntersectionPortsForProtocols(Arg1:list)string
			Args:
				args[0] is Arg1 (list(str)): A list of protocol names.

			Returns:
				str: The list of port IDs that have all the given protocols configured.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getIntersectionPortsForProtocols', payload=payload, response_object=None)

	def GetIxVmCardByIp(self, *args, **kwargs):
		"""Executes the getIxVmCardByIp operation on the server.

		Obtain IxVM card ID by providing management IP address.

		getIxVmCardByIp(Arg1:string)number
			Args:
				args[0] is Arg1 (str): Management IP address of the card.

			Returns:
				number: Returns the card ID which has corresponding IP address on the management interface.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getIxVmCardByIp', payload=payload, response_object=None)

	def GetMemoryUsageInfo(self):
		"""Executes the getMemoryUsageInfo operation on the server.

		Retrieve memory usage information

			Returns:
				str: String containing memory usage: virtual, private, peak virtual bytes and bytes in all heaps

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getMemoryUsageInfo', payload=payload, response_object=None)

	def GetNetworkGroupSize(self):
		"""Executes the getNetworkGroupSize operation on the server.

			Returns:
				list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*],arg2:list[dict(arg1:str,arg2:number)])): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getNetworkGroupSize', payload=payload, response_object=None)

	def GetPortsForProtocol(self, *args, **kwargs):
		"""Executes the getPortsForProtocol operation on the server.

		The command to get ports for the protocol.

		getPortsForProtocol(Arg1:string)string
			Args:
				args[0] is Arg1 (str): Protocol name.

			Returns:
				str: A string with all the port IDs having the protocol configured.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getPortsForProtocol', payload=payload, response_object=None)

	def GetRbMemoryUsageInfo(self):
		"""Executes the getRbMemoryUsageInfo operation on the server.

		Fetch the memory usage information by RB protocols.

			Returns:
				str: Returns memory usage information by RB protocols.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getRbMemoryUsageInfo', payload=payload, response_object=None)

	def GetRecommendedSettings(self, *args, **kwargs):
		"""Executes the getRecommendedSettings operation on the server.

		It will get the recommended settings for the given copper type. Available choices are: oneMeter, threeMeters, fiveMeters.

		getRecommendedSettings(Arg1:string, Arg2:list)
			Args:
				args[0] is Arg1 (str): 
				args[1] is Arg2 (list(str[None|/api/v1/sessions/1/ixnetwork/availableHardware?deepchild=port])): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getRecommendedSettings', payload=payload, response_object=None)

	def GetSlotLicenseInUse(self, *args, **kwargs):
		"""Executes the getSlotLicenseInUse operation on the server.

		This exec returns a list of slots/cards of the chassis that are currently using the AppLibrary Slot Licenses.

		getSlotLicenseInUse(Arg1:string)list
			Args:
				args[0] is Arg1 (str): The IPv4 address of the chassis.

			Returns:
				list(number): An array of slot/card numbers of the chassis that currently checked-out AppLibrary Slot Licenses.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getSlotLicenseInUse', payload=payload, response_object=None)

	def GetTapSettings(self):
		"""Executes the getTapSettings operation on the server.

		Get TAP Settings for all the connected chassis.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getTapSettings', payload=payload, response_object=None)

	def GetTopologyStatus(self):
		"""Executes the getTopologyStatus operation on the server.

			Returns:
				list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*],arg2:list[dict(arg1:str,arg2:number)],arg3:str[notstarted\~starting\~started\~stopping\~error\~mixed])): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('getTopologyStatus', payload=payload, response_object=None)

	def GetUnionPortsForProtocols(self, *args, **kwargs):
		"""Executes the getUnionPortsForProtocols operation on the server.

		The command to get union ports for the protocols.

		getUnionPortsForProtocols(Arg1:list)string
			Args:
				args[0] is Arg1 (list(str)): A list of protocol names.

			Returns:
				str: The list of port IDs that have at least one of the given protocols configured.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getUnionPortsForProtocols', payload=payload, response_object=None)

	def HwRebootCardByIDs(self, *args, **kwargs):
		"""Executes the hwRebootCardByIDs operation on the server.

		Perform hard reboot on virtual cards.

		hwRebootCardByIDs(Arg1:list)bool
			Args:
				args[0] is Arg1 (list(number)): An array of card IDs.

			Returns:
				bool: Returns whether or not the command is successful.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('hwRebootCardByIDs', payload=payload, response_object=None)

	def IgmpJoin(self, *args, **kwargs):
		"""Executes the igmpJoin operation on the server.

		Executing this command sends IGMP join message.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		igmpJoin(Arg1:string)
			Args:
				args[0] is Arg1 (str): This is a multicast IPv4 address as an argument to igmpJoin.

		igmpJoin(Arg1:string, Arg2:number)
			Args:
				args[0] is Arg1 (str): This is a multicast IPv4 address as an argument to igmpJoin.
				args[1] is Arg2 (number): This is an integer value as an argument to igmpJoin.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('igmpJoin', payload=payload, response_object=None)

	def IgmpLeave(self, *args, **kwargs):
		"""Executes the igmpLeave operation on the server.

		Executing this command sends IGMP leave message.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		igmpLeave(Arg1:string)
			Args:
				args[0] is Arg1 (str): This is a multicast IPv4 address as an argument to igmpLeave.

		igmpLeave(Arg1:string, Arg2:number)
			Args:
				args[0] is Arg1 (str): This is a multicast IPv4 address as an argument to igmpLeave.
				args[1] is Arg2 (number): This is an integer value as an argument to igmpLeave.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('igmpLeave', payload=payload, response_object=None)

	def Import(self, *args, **kwargs):
		"""Executes the import operation on the server.

		Imports a legacy IxAutomate configuration from the specified file.

		import(File:string)
			Args:
				args[0] is File (str): The IxAutomate configuration file that will be imported.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('import', payload=payload, response_object=None)

	def LoadConfig(self, *args, **kwargs):
		"""Executes the loadConfig operation on the server.

		Load an existing configuration file.

		loadConfig(Arg1:href)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A readFrom file handle

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('loadConfig', payload=payload, response_object=None)

	def LoadTopology(self, *args, **kwargs):
		"""Executes the loadTopology operation on the server.

		Load a chassis topology from file.

		loadTopology(Arg1:string)string
			Args:
				args[0] is Arg1 (str): Path to the CSV configuration file.

			Returns:
				str: Returns an array of objects containing information about each port from the loaded chassis topology.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('loadTopology', payload=payload, response_object=None)

	def MergeCapture(self, *args, **kwargs):
		"""Executes the mergeCapture operation on the server.

		This command will merge one offline capture with on running capture.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mergeCapture(Arg1:string, Arg2:href, Arg3:enum, Arg4:string)
			Args:
				args[0] is Arg1 (str): Full path to the capture file.
				args[1] is Arg2 (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=capture)): The port capture object.
				args[2] is Arg3 (str(control|data)): The type of the capture, either data or control.
				args[3] is Arg4 (str): The full path where the resulted merged capture will be saved, the resulted capture name needs to contain extension also.

		mergeCapture(Arg1:string, Arg2:string, Arg3:string)
			Args:
				args[0] is Arg1 (str): Full path to the first capture file.
				args[1] is Arg2 (str): Full path to the second capture file.
				args[2] is Arg3 (str): The full path where the resulted merged capture will be saved, the result capture name needs to contain extension also.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mergeCapture', payload=payload, response_object=None)

	def NewConfig(self):
		"""Executes the newConfig operation on the server.

		Clear the current configuration and create an empty configuration.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('newConfig', payload=payload, response_object=None)

	def RebootVirtualChassis(self):
		"""Executes the rebootVirtualChassis operation on the server.

		Perform hard reboot on the connected virtual chassis.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('rebootVirtualChassis', payload=payload, response_object=None)

	def RebuildChassisTopology(self, *args, **kwargs):
		"""Executes the rebuildChassisTopology operation on the server.

		Rebuild the chassis topology using automatically discovered appliances.

		rebuildChassisTopology(Arg1:string, Arg2:bool, Arg3:bool)
			Args:
				args[0] is Arg1 (str): IxNetwork version that should be used to filter appliances.
				args[1] is Arg2 (bool): Flag that enables reconfiguration on the same slots for the previous cards.
				args[2] is Arg3 (bool): Promiscuous mode.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('rebuildChassisTopology', payload=payload, response_object=None)

	def RediscoverAppliances(self):
		"""Executes the rediscoverAppliances operation on the server.

		Return a list of discovered machines after performing rediscovery on all systems.

			Returns:
				str: Returns a list of discovered machines in XML format.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('rediscoverAppliances', payload=payload, response_object=None)

	def Refresh(self, *args, **kwargs):
		"""Executes the refresh operation on the server.

		NOT DEFINED

		refresh(Arg1:string)
			Args:
				args[0] is Arg1 (str): NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('refresh', payload=payload, response_object=None)

	def RefreshChassisTopology(self):
		"""Executes the refreshChassisTopology operation on the server.

		Obtain updated configuration of the chassis topology.

			Returns:
				str: Returns an array of objects containing information about each port from the new chassis topology.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('refreshChassisTopology', payload=payload, response_object=None)

	def RemoveAllTclViews(self):
		"""Executes the removeAllTclViews operation on the server.

		Deletes all the views that were created from using this API.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('removeAllTclViews', payload=payload, response_object=None)

	def SaveCapture(self, *args, **kwargs):
		"""Executes the saveCapture operation on the server.

		This command saves the current capture data to the specified directory.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		DEPRECATED saveCapture(Arg1:string)
			Args:
				args[0] is Arg1 (str): Directory for saving the captures

		DEPRECATED saveCapture(Arg1:string, Arg2:string)
			Args:
				args[0] is Arg1 (str): Directory for saving the captures
				args[1] is Arg2 (str): Suffix used for naming the capture files

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('saveCapture', payload=payload, response_object=None)

	def SaveCaptureFiles(self, *args, **kwargs):
		"""Executes the saveCaptureFiles operation on the server.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		saveCaptureFiles(Arg1:string)list
			Args:
				args[0] is Arg1 (str): Directory for saving the captures

			Returns:
				list(str): A list of relative paths of all the captures saved

		saveCaptureFiles(Arg1:string, Arg2:string)list
			Args:
				args[0] is Arg1 (str): Directory for saving the captures
				args[1] is Arg2 (str): Suffix used for naming the capture files

			Returns:
				list(str): A list of relative paths of all the captures saved

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('saveCaptureFiles', payload=payload, response_object=None)

	def SaveConfig(self, *args, **kwargs):
		"""Executes the saveConfig operation on the server.

		Save the current configuration to a file.

		saveConfig(Arg1:href)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('saveConfig', payload=payload, response_object=None)

	def Scriptgen(self, *args, **kwargs):
		"""Executes the scriptgen operation on the server.

		Create a script of the current configuration.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		scriptgen()string

			Returns:
				str: A string value.

		DEPRECATED scriptgen(Arg1:href)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A valid output file handle from the ixNet writeTo command.

		DEPRECATED scriptgen(Arg1:href, Arg2:string)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.
				args[1] is Arg2 (str): A string value.

		DEPRECATED scriptgen(Arg1:href, Arg2:string, Arg3:list)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.
				args[1] is Arg2 (str): The type of script to create.
				args[2] is Arg3 (list(str)): The scriptgen options.

		DEPRECATED scriptgen(Arg1:href, Arg2:string, Arg3:list, Arg4:number, Arg5:number)
			Args:
				args[0] is Arg1 (obj(ixnetwork_restpy.files.Files)): A writeTo file handle.
				args[1] is Arg2 (str): A string value.
				args[2] is Arg3 (list(str)): A list of string values.
				args[3] is Arg4 (number): An integer.
				args[4] is Arg5 (number): An integer.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('scriptgen', payload=payload, response_object=None)

	def Select(self, *args, **kwargs):
		"""Executes the select operation on the server.

		Select nodes and properties from the hierarchy

		select(Selects:list)string
			Args:
				args[0] is Selects (list(dict(from:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],properties:list[str],children:list[dict(child:str,properties:list[str],filters:list[dict(property:str,regex:str)])],inlines:list[dict(child:str,properties:list[str])]))): A list of select structures.Each select structure consists of a starting point in the hierarchy. This starting point must exist and is defined as the 'from' value.Properties for the 'from' value are optional and can be retrieved using the 'properties' list.To retrieve all properties specify the '*' wildcard. Regex is not supported in the 'properties' list.Individual nodes under the starting point can be retrieved. These are specified in the 'children' list.Each item in the children list contains a 'child' name, a list of 'properties' and a list of filters by which to reduce the result set.The 'child' name can be a single name or a regex.Properties that reference another object can have that object's content inlined by specifying inline children.Any child nodes below the object reference can be expanded as long as they are specified in the inline children.

			Returns:
				str: A json encoded string of result sets.The encoded string will contain a list of result sets with each select producing a result set.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('select', payload=payload, response_object=None)

	def SendArpAll(self):
		"""Executes the sendArpAll operation on the server.

		Send ARP for all interfaces.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('sendArpAll', payload=payload, response_object=None)

	def SendNsAll(self):
		"""Executes the sendNsAll operation on the server.

		Send neighbor solicitation to all interfaces.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('sendNsAll', payload=payload, response_object=None)

	def SendRsAll(self):
		"""Executes the sendRsAll operation on the server.

		Send router solicitation to all interfaces.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('sendRsAll', payload=payload, response_object=None)

	def SetGuardRailVersion(self, *args, **kwargs):
		"""Executes the setGuardRailVersion operation on the server.

		Disables GuardRail for TCL.

		setGuardRailVersion(Arg1:string)
			Args:
				args[0] is Arg1 (str): Deprecated.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('setGuardRailVersion', payload=payload, response_object=None)

	def SetLoggingLevel(self, *args, **kwargs):
		"""Executes the setLoggingLevel operation on the server.

		setLoggingLevel(Arg1:enum)
			Args:
				args[0] is Arg1 (str(kDebug|kError|kFatal|kInfo|kNothing|kWarn)): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('setLoggingLevel', payload=payload, response_object=None)

	def SetPortTransmitDuration(self, *args, **kwargs):
		"""Executes the setPortTransmitDuration operation on the server.

		Set the port transmit duration.

		setPortTransmitDuration(Arg1:list)
			Args:
				args[0] is Arg1 (list(dict(arg1:number,arg2:list[str[None|/api/v1/sessions/1/ixnetwork/lag|/api/v1/sessions/1/ixnetwork/traffic|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficItem|/api/v1/sessions/1/ixnetwork/traffic?deepchild=highLevelStream|/api/v1/sessions/1/ixnetwork/vport]]))): An array of structures. Each structure is an duration and a valid object reference.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('setPortTransmitDuration', payload=payload, response_object=None)

	def SetSnapshotSettingsToDefault(self, *args, **kwargs):
		"""Executes the SetSnapshotSettingsToDefault operation on the server.

		Set the settings of snapshot to default.

		SetSnapshotSettingsToDefault(Arg1:string)
			Args:
				args[0] is Arg1 (str): The setting name.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('SetSnapshotSettingsToDefault', payload=payload, response_object=None)

	def SetTapSettings(self):
		"""Executes the setTapSettings operation on the server.

		Send TAP Settings to IxServer for all the connected chassis.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('setTapSettings', payload=payload, response_object=None)

	def StartAllProtocols(self, *args, **kwargs):
		"""Executes the startAllProtocols operation on the server.

		Starts all configured protocols under /vport/protocols, /vport/protocolStack and /topology

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		startAllProtocols()

		startAllProtocols(Arg1:enum)
			Args:
				args[0] is Arg1 (str(async|sync)): An enum indicating whether or not the exec will be executed synchronously or asynsynchronously

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('startAllProtocols', payload=payload, response_object=None)

	def StartCapture(self):
		"""Executes the startCapture operation on the server.

		The command to start the packet capture for the selected port or group of ports.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('startCapture', payload=payload, response_object=None)

	def StartTestConfiguration(self, *args, **kwargs):
		"""Executes the startTestConfiguration operation on the server.

		Starts the first Quick Test found in the current configuration.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		startTestConfiguration()

		startTestConfiguration(TestName:string)
			Args:
				args[0] is TestName (str): The name of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('startTestConfiguration', payload=payload, response_object=None)

	def StopAllProtocols(self, *args, **kwargs):
		"""Executes the stopAllProtocols operation on the server.

		Stops all configured protocols under /vport/protocols, /vport/protocolStack and /topology

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopAllProtocols()

		stopAllProtocols(Arg1:enum)
			Args:
				args[0] is Arg1 (str(async|sync)): An enum indicating whether or not the exec will be executed synchronously or asynsynchronously

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopAllProtocols', payload=payload, response_object=None)

	def StopCapture(self):
		"""Executes the stopCapture operation on the server.

		The command to stop the packet capture on the selected port or group of ports.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('stopCapture', payload=payload, response_object=None)

	def StopTestConfiguration(self):
		"""Executes the stopTestConfiguration operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = None
		return self._execute('stopTestConfiguration', payload=payload, response_object=None)

	def SyncStatisticsStartTimeWithClientClock(self, *args, **kwargs):
		"""Executes the syncStatisticsStartTimeWithClientClock operation on the server.

		Make the statistics timestamps relative to the time on the client machine or relative to the test start.

		syncStatisticsStartTimeWithClientClock(Arg1:bool)
			Args:
				args[0] is Arg1 (bool): True = relative to system time, false = relative to test start.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('syncStatisticsStartTimeWithClientClock', payload=payload, response_object=None)

	def TakeViewCSVSnapshot(self, *args, **kwargs):
		"""Executes the TakeViewCSVSnapshot operation on the server.

		Performs Snapshot CSV on the given views.

		TakeViewCSVSnapshot(Arg1:list, Arg2:list)
			Args:
				args[0] is Arg1 (list(str)): A list of views for which to take a snapshot.
				args[1] is Arg2 (list(str)): A list of settings, given in the form of SettingName:SettingValue.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('TakeViewCSVSnapshot', payload=payload, response_object=None)

	def WaitForLicenseBroadcast(self, *args, **kwargs):
		"""Executes the waitForLicenseBroadcast operation on the server.

		Wait for the license broadcast to be complete.

		waitForLicenseBroadcast(Arg1:number)
			Args:
				args[0] is Arg1 (number): Seconds to wait.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = {}
		for i in range(len(args)): payload['Arg%s' % (i + 1)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('waitForLicenseBroadcast', payload=payload, response_object=None)
